@@ -22,6 +22,18 @@ class JobDescriptionModel(CommonModel):
         # call parent class for validating
         super().__init__(excels,output_excel_file,globals())
 
+    def context(self,*args, **kwargs):
+        context= {
+            **self.dict(),
+            "requirements":self.joboffer.requirements
+        }
+        return context
+    
+    def make_pdf_form(self, *args, **kwargs):
+        pass
+    
+    def make_web_form(self, *args, **kwargs):
+        pass
 
 class JobDescriptionDocxAdaptor():
     def __init__(self,jobdescription_obj:JobDescriptionModel):
