@@ -130,6 +130,12 @@ class Wp(DurationModel):
     caq_number: Optional[str]
     expiry_date: Optional[date]
 
+    @validator("brief_duties")
+    def longer_than_5(cls, v):
+        if len(v) < 5:
+            raise ValueError("must longer than 5 characters")
+        return v
+
     @root_validator
     def checkLMIA_OfferNum(cls, values):
         work_permit_type = values.get("work_permit_type")
@@ -210,6 +216,23 @@ class WpInCanada(DurationModel):
     lmia_num_or_offer_num: Optional[str]
     pnp_certificated: bool
 
+    @validator("brief_duties")
+    def longer_than_5(cls, v):
+        if len(v) < 5:
+            raise ValueError("must longer than 5 characters")
+        return v
+
+    @root_validator
+    def lmia_number_check(cls, values):
+        wp_type = values.get("work_permit_type")
+        number = values.get("lmia_num_or_offer_num")
+        if wp_type == "Labour Market Impact Assessment Stream" and (
+            int(number) < 6000000 or int(number) > 99999999
+        ):
+            raise ValueError("LMIA number must between 6,000,000  and 99,999,999")
+
+        return values
+
     @root_validator
     def checkLMIA_OfferNum(cls, values):
         work_permit_type = values.get("work_permit_type")
