@@ -18,8 +18,8 @@ class General(BaseModel):
     has_bc_employer_certificate: Optional[bool]
     company_intro: str
     business_intro: str
-    ft_employee_number:int
-    pt_employee_number:int
+    ft_employee_number: int
+    pt_employee_number: int
 
 
 class ErAddress(Address):
@@ -127,7 +127,7 @@ class Joboffer(JobofferBase):
         oral = values.get("oral", None)
         writing = values.get("writing", None)
         reason_for_no = values.get("reason_for_no", None)
-        if english_french and not oral or not writing:
+        if english_french and (not oral or not writing):
             raise ValueError(
                 "Since English or French is true, but did not input oral or/and writting language requirement"
             )
