@@ -74,7 +74,7 @@ salary_payment_way = {
     "source": ["weekly", "bi-weekly", "semi-monthly", "monthly"],
 }
 wage_unit = {"validate": "list", "source": ["hourly", "weekly", "monthly", "annually"]}
-lmia_duration_unit = {"validate": "list", "source": ["month", "year"]}
+lmia_duration_unit = {"validate": "list", "source": ["months", "years"]}
 ot_after_hours_unit = {"validate": "list", "source": ["day", "week"]}
 job_duration_unit = {"validate": "list", "source": ["day", "week", "month", "year"]}
 purpose_of_lmia = {
@@ -406,8 +406,8 @@ validation = {
         "establish_date": date_format,
         "has_lmia_approved": yes_no,
         "corporate_structure": corporate_structure,
-        "num_pnps": positive_int,
-        "num_pnps_approved": positive_int,
+        "num_pnps": positive_int_include_zero,
+        "num_pnps_approved": positive_int_include_zero,
         "num_pnps_in_process": positive_int_include_zero,
         "when_lmia_approved": date_format,
         "last_revenue": positive_int_decimal,
