@@ -1,7 +1,4 @@
-from webform.models.bcpnpmodel_app import BcpnpEEModelApp, BcpnpModelApp
-from webform.models.definition import Action
-from webform.models.bcpnpmodel_reg import BcpnpModelReg, BcpnpEEModelReg
-from webform.bcpnp.dashboard import DashboardApp, DashboardReg
+from webform.definition import Action
 from model.common.educationbase import EducationHistory
 from webform.bcpnp.data import (
     getEducation,
@@ -11,10 +8,12 @@ from webform.bcpnp.data import (
     getFieldofStudy,
 )
 from typing import Union
+from utils.utils import best_match
+from webform.bcpnp.dateinput import inputDate, pressEnter
 
 
 class EducationApp:
-    def __init__(self, person: Union[BcpnpModelApp, BcpnpEEModelApp]):
+    def __init__(self, person: object):
         self.person = person
 
     @property
@@ -23,6 +22,7 @@ class EducationApp:
         high_school = EducationHistory(self.person.education).high_school
 
         for index, edu in enumerate(high_school):
+            country = best_match(edu.country, country_map.keys())
             block = [
                 {
                     "action_type": Action.Input.value,
@@ -32,6 +32,7 @@ class EducationApp:
                     "length": 10,
                     "required": True,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Input.value,
                     "label": "To",
@@ -40,6 +41,7 @@ class EducationApp:
                     "length": 10,
                     "required": True,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Checkbox.value,
                     "label": "Currently Enrolled",
@@ -66,7 +68,7 @@ class EducationApp:
                     "action_type": Action.Select.value,
                     "label": "Country",
                     "id": "#BCPNP_App_EduSec_Country-" + str(index),
-                    "value": country_map[edu.country],
+                    "value": country_map[country],
                 },
                 {
                     "action_type": Action.Radio.value,
@@ -100,23 +102,22 @@ class EducationApp:
             else "#BCPNP_App_EduBC-No",
         }
         for index, edu in enumerate(education):
+            city = best_match(edu.city, city_map.keys())
+            from_date = inputDate(
+                "From",
+                "#BCPNP_App_EduBC_From-" + str(index),
+                edu.start_date,
+                with_enter=True,
+            )
+            to_date = inputDate(
+                "To",
+                "#syncA_App_EduBC_To-" + str(index),
+                edu.start_date,
+                with_enter=True,
+            )
             block = [
-                {
-                    "action_type": Action.Input.value,
-                    "label": "From",
-                    "id": "#BCPNP_App_EduBC_From-" + str(index),
-                    "value": edu.start_date,
-                    "length": 10,
-                    "required": True,
-                },
-                {
-                    "action_type": Action.Input.value,
-                    "label": "To",
-                    "id": "#syncA_App_EduBC_To-" + str(index),
-                    "value": edu.end_date,
-                    "length": 10,
-                    "required": True,
-                },
+                *from_date,
+                *to_date,
                 {
                     "action_type": Action.Checkbox.value,
                     "label": "Currently Enrolled",
@@ -135,7 +136,7 @@ class EducationApp:
                     "action_type": Action.Select.value,
                     "label": "City/town",
                     "id": "#syncA_App_EduBC_City-" + str(index),
-                    "value": city_map[edu.city],
+                    "value": city_map[city],
                 },
                 {
                     "action_type": Action.Select.value,
@@ -202,6 +203,7 @@ class EducationApp:
                     "length": 10,
                     "required": True,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Input.value,
                     "label": "To",
@@ -210,6 +212,7 @@ class EducationApp:
                     "length": 10,
                     "required": True,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Checkbox.value,
                     "label": "Currently Enrolled",
@@ -290,6 +293,7 @@ class EducationApp:
             else "#BCPNP_App_EduNCAN-No",
         }
         for index, edu in enumerate(education):
+            country = best_match(edu.country, country_map)
             block = [
                 {
                     "action_type": Action.Input.value,
@@ -299,6 +303,7 @@ class EducationApp:
                     "length": 10,
                     "required": True,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Input.value,
                     "label": "To",
@@ -307,6 +312,7 @@ class EducationApp:
                     "length": 10,
                     "required": True,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Checkbox.value,
                     "label": "Currently Enrolled",
@@ -331,7 +337,7 @@ class EducationApp:
                     "action_type": Action.Select.value,
                     "label": "Country",
                     "id": "#BCPNP_App_EduPostSec_Country-" + str(index),
-                    "value": country_map[edu.country],
+                    "value": country_map[country],
                 },
                 {
                     "action_type": Action.Select.value,
@@ -409,6 +415,6 @@ class EducationApp:
                 "page_name": "Education",
                 "actions": actions,
                 "id": "body > div > main > div.layout-container > div > div > div > uf-form > div > ng-transclude > div > uf-tabset > div > ul > li:nth-child(3) > a",
-                "next_page_tag":"#BCPNP_App_WorkExp-No"
+                "next_page_tag": "#BCPNP_App_WorkExp-No",
             }
         ]
