@@ -1,16 +1,17 @@
 from typing import List, Union
-from webform.models.definition import Action
-from webform.models.bcpnpmodel_app import BcpnpModelApp, BcpnpEEModelApp
+from webform.definition import Action
 from webform.bcpnp.dashboard import DashboardApp
 from model.common.employmenthistory import EmploymentHistory
 from datetime import datetime
 from webform.bcpnp.data import country_map
 from model.common.family import FamilyMembers
 from webform.bcpnp.data import marriage_map, province_map, family_imm_status_canada_map
+from utils.utils import best_match
+from webform.bcpnp.dateinput import inputDate, pressEnter
 
 
-class Family:
-    def __init__(self, person: Union[BcpnpModelApp, BcpnpEEModelApp]):
+class FamilyApp:
+    def __init__(self, person: object):
         self.person = person
         self.spouse = FamilyMembers(self.person.family).spouse
         self.dependants = FamilyMembers(self.person.family).dependants
@@ -29,8 +30,15 @@ class Family:
                 else "#syncA_App_MaritalStatus-No",
             }
         ]
-        sp = (
-            [
+        if self.person.marriage.marital_status in ["Common-Law", "Married"]:
+            spouse_birth_country = best_match(
+                self.spouse.birth_country, country_map.keys()
+            )
+            spouse_citizen_country = best_match(
+                self.spouse.country_of_citizenship, country_map.keys()
+            )
+
+            sp = [
                 {
                     "action_type": Action.Input.value,
                     "label": "Family name",
@@ -63,17 +71,18 @@ class Family:
                     "required": True,
                     "length": 100,
                 },
+                pressEnter(),
                 {
                     "action_type": Action.Select.value,
                     "label": "Country of birth",
                     "id": "#syncA_App_Spouse_BirthPlace",
-                    "value": country_map[self.spouse.birth_country],
+                    "value": country_map[spouse_birth_country],
                 },
                 {
                     "action_type": Action.Select.value,
                     "label": "Country of citizen",
                     "id": "#syncA_App_Spouse_Citizenship",
-                    "value": country_map[self.spouse.country_of_citizenship],
+                    "value": country_map[spouse_citizen_country],
                 },
                 {
                     "action_type": Action.Input.value,
@@ -91,10 +100,11 @@ class Family:
                     "required": True,
                     "length": 10,
                 },
+                pressEnter(),
             ]
-            if self.person.marriage.marital_status in ["Common-Law", "Married"]
-            else []
-        )
+        else:
+            sp = []
+
         in_canada = [
             {
                 "action_type": Action.Radio.value,
@@ -141,7 +151,8 @@ class Family:
                     "value": self.person.marriage.sp_canada_status_end_date,
                     "required": True,
                     "length": 10,
-                }
+                },
+                pressEnter(),
             ]
             if self.person.marriage.sp_canada_status
             in ["Worker", "Student", "Visitor", "Other"]
@@ -199,6 +210,12 @@ class Family:
         )
 
     def dependant_block(self, dependant, index):
+        dependant_birth_country = best_match(
+            dependant.birth_country, country_map.keys()
+        )
+        dependant_citizen_country = best_match(
+            dependant.country_of_citizenship, country_map.keys()
+        )
         return [
             {
                 "action_type": Action.Input.value,
@@ -224,17 +241,18 @@ class Family:
                 "required": True,
                 "length": 10,
             },
+            pressEnter(),
             {
                 "action_type": Action.Select.value,
                 "label": "Country of birth",
                 "id": f"#BCPNP_App_Child_BirthPlace-{index}",
-                "value": country_map[dependant.birth_country],
+                "value": country_map[dependant_birth_country],
             },
             {
                 "action_type": Action.Select.value,
                 "label": "Citizen country",
                 "id": f"#BCPNP_App_Child_Citizenship-{index}",
-                "value": country_map[dependant.country_of_citizenship],
+                "value": country_map[dependant_citizen_country],
             },
             {
                 "action_type": Action.Input.value,
@@ -248,6 +266,7 @@ class Family:
 
     def sibling_block(self, sibling, index):
         sibling_deceased = True if sibling.date_of_death else False
+        sibling_birth_country = best_match(sibling.birth_country, country_map.keys())
         basic = [
             {
                 "action_type": Action.Input.value,
@@ -273,11 +292,12 @@ class Family:
                 "required": True,
                 "length": 10,
             },
+            pressEnter(),
             {
                 "action_type": Action.Select.value,
                 "label": "Country of birth",
                 "id": f"#BCPNP_App_Sibling_BirthPlace-{index}",
-                "value": country_map[sibling.birth_country],
+                "value": country_map[sibling_birth_country],
             },
             {
                 "action_type": Action.Select.value,
@@ -288,7 +308,7 @@ class Family:
             {
                 "action_type": Action.Checkbox.value,
                 "label": "Deceased?",
-                "id":f"#BCPNP_App_Sibling_Deceased-{index}" ,
+                "id": f"#BCPNP_App_Sibling_Deceased-{index}",
                 "value": sibling_deceased,
             },
         ]
@@ -411,6 +431,8 @@ class Family:
     def parents(self):
         mother_deceased = True if self.mother.date_of_death else False
         father_deceased = True if self.father.date_of_death else False
+        mother_birth_country = best_match(self.mother.birth_country, country_map.keys())
+        father_birth_country = best_match(self.father.birth_country, country_map.keys())
         mother = [
             {
                 "action_type": Action.Input.value,
@@ -436,11 +458,12 @@ class Family:
                 "required": True,
                 "length": 10,
             },
+            pressEnter(),
             {
                 "action_type": Action.Select.value,
                 "label": "Country of birth",
                 "id": "#BCPNP_App_Mother_BirthPlace",
-                "value": country_map[self.mother.birth_country],
+                "value": country_map[mother_birth_country],
             },
             {
                 "action_type": Action.Checkbox.value,
@@ -489,11 +512,12 @@ class Family:
                 "required": True,
                 "length": 10,
             },
+            pressEnter(),
             {
                 "action_type": Action.Select.value,
                 "label": "Country of birth",
                 "id": "#BCPNP_App_Father_BirthPlace",
-                "value": country_map[self.father.birth_country],
+                "value": country_map[father_birth_country],
             },
             {
                 "action_type": Action.Checkbox.value,
@@ -583,6 +607,6 @@ class Family:
                 "page_name": "Family",
                 "actions": actions,
                 "id": "body > div > main > div.layout-container > div > div > div > uf-form > div > ng-transclude > div > uf-tabset > div > ul > li:nth-child(5) > a",
-                "next_page_tag":"#syncA_App_FullTimeEmpOffer-No"
+                "next_page_tag": "#syncA_App_FullTimeEmpOffer-No",
             }
         ]
