@@ -1,4 +1,4 @@
-from webform.models.definition import Action
+from webform.definition import Action
 import base64
 
 
@@ -28,9 +28,16 @@ class Login:
                         "password": self.encode(self.rcic_account["password"]),
                         "account_element_id": "#username",
                         "password_element_id": "#password",
-                        "login_button_id": "body > pra-root > pra-localized-app > main > div > pra-login-page > pra-login > div > div > form > button",
                     },
                 ],
-                "id": None,
-            }
+                "id": "body > pra-root > pra-localized-app > main > div > pra-login-page > pra-login > div > div > form > button",
+                "next_page_tag": "body > pra-root > pra-localized-app > main > div > pra-home-page > div > div > div > pra-card:nth-child(1) > div > div > div > a.btn.btn-secondary.card__all-apps-btn",
+            },
+            {
+                "action_type": Action.WebPage.value,
+                "page_name": "Select existing application",
+                "actions": [],
+                "id": "body > pra-root > pra-localized-app > main > div > pra-home-page > div > div > div > pra-card:nth-child(1) > div > div > div > a.btn.btn-secondary.card__all-apps-btn",
+                "next_page_tag": "body > pra-root > pra-localized-app > main > div > pra-rep-dashboard > div > div.search-row.ng-star-inserted > div > button",
+            },
         ]
